bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 31. Aventiure
___________________________________________________ #### Aventivre wie die herren #### ze kirchen giengen
###### 1849 | ### Mir chvlent so di ringe | so sprach volker ### ia waene div naht vns welle | nv niht wern mer ### ich chivs ez von dem lvfte | ez ist schiere tach ### do wachten si do manigen | der noch slaffende lach
###### 1850 | ### do erschein der liehte morgen | den gesten in den sal ### hagen begonde wechen | di ritter veber al ### ob si zv dem mvenster | cer messe wolden gan ### nach sitten cristenliche | man vil livten began
###### 1851 | ### si svngen vngeliche | daz da vil wol schein ### cristen vnde heiden | di warn niht enein ### do wolden zv der kirchen | di gventheres man ### si waren von den betten | al geliche gestan
###### 1852 | ### do naeten sich di rechen | in also gvt gewant ### daz nie helde maere | in deheines chveneges lant ### ie bezzer kleider braten | daz was hagenen leit ### er sprach ia svlt ir helde | hi tragen anderiv chleit
###### 1853 | ### ia sint iv doch genvgen | div maere wol bechant ### nv trage fver di rosen | div waffen an der hant ### fver shapel wol gesteinet | di liehten helme gvt ### sit daz wir wol erchennen | der argen criemhilden mvot
###### 1854 | ### wir mvzen hivte striten | daz wil ich iv sagen ### ir svlt fver siden hemde | di halsperge tragen ### vnd fver di richen mentel | di gvten schilde wit ### ob iemen mit iv zvrne | daz ir vil werliche sit
###### 1855 | ### mine lieben | darzv mage vnd man ### ir svlt vil willechlichen | zv der kirchen gan ### vnde chlaget got dem richen | iwer sorge vnd iwer not ### vnd wizzet sicherlichen | daz vns nahet der tot
###### 1856 | ### irn svlt ovch niht vergezen | swaz ir habet getan ### vnde svlt vil vlizzechliche | da gein gote stan ### des wil ich ivch warnen | rechen vil her ### ez en welle got von himle | ir vernemet messe nimmer mer
###### 1857 | ### svs giengen zv dem mvenster | di fvrsten vnd ir man ### vf dem vronem vrithove | da hiez si stille stan ### hagen der chvene | daz si sich schieden niht ### er sprach ia weiz ez noch niemen | waz von den hivnen vns geschit
###### 1858 | ### leget mine frivnde | di schilde fver den fvz ### vnde geltet ob iv iemen welle | bieten swachen grvz ### mit tieffen verchwunden | daz ist hagenen rat ### daz ir so werdet fvnden | daz ez iv lobelichen stat
###### 1859 | ### volker vnd hagene | di zwene giengen dan ### fver daz wite mvenster | daz wart dvrh daz getan ### daz si daz wolden wizen | daz des chveneges wip ### mvse mit in dringen | ia was vil grimmech ir lip
###### 1860 | ### do chom der wirt des landes | vnd ovh sin schoene wip ### mit richem gewande | gezieret was ir lip ### vnd ovch vil sneller rechen | di man sach mit ir varn ### do chos man hohe stovben | von der criemhilde scharn
###### 1861 | ### do der chvenech riche | svs gewaffent sach ### di chvenege vnd ir gesinde | wi balde er do sprach ### wi sihe ich frivnde mine | vnder helme gan ### mir ist leit vf mine triwe | vnd hat in iemen iht getan
###### 1862 | ### ich solz in bvezen gerne | swi si dvnchet gvt ### hat iemen in besweret | daz herce vnd ovch den mvt ### des bringe ich si wol innen | daz ez mir ist vil leit ### swaz si mir gebietent | des pin ich in alles bereit
###### 1863 | ### des antwurte hagene | vns hat niemen niht getan ### ez ist sitte miner herren | daz si gewaffent gan ### zallen hohgeziten | ce vollen drien tagen ### swaz man vns hi getaete | wir soltenz eceln sagen
###### 1864 | ### vil wol horte criemhilt | waz do hagen sprach ### wi rehte fientliche | si im vnder sach ### si ne wolde doch niht melden | den site von ir lant ### swi lange si den hete daz | cen bvrgonden bechant
###### 1865 | ### swi grimme vnd swi starch | si in vient waere ### het im iemen gesagt | div rehten maere ### er het wol vnderstanden | daz doch sit da geshach ### dvrch ir vil starche vbermvt | ir deheiner im es veriach
###### 1866 | ### do gi vil groziv menege | mit der chveneginne dan ### do ne wolden dise zwene | doch niht hoher stan ### zweir hande breite | daz was den hivnen leit ### ia mvsen si sich dringen | mit den helden gemeit
###### 1867 | ### eceln kameraere | di ne dvhte daz niht gvt ### ia heten si den rechen | erzvernet do den mvt ### wan daz si ne torsten | vor dem chvenege her ### da was vil michel dringen | vnt do niht anders mer
###### 1868 | ### do man da gote gediende | vnt daz si wolden dan ### vil balde chom cen rossen | vil manech hivnen man ### do was bi criemhilde | manech schoniv meit ### wol siben tvsent degene | bi der chveneginne reit
###### 1869 | ### criemhilt mit ir vrowen | in div venster gesaz ### zv ecel dem richen richen | vil liep was im daz ### si wolden schowen riten | di helde vil gemeit ### hey waz vremder recken | vor in vf dem hove reit
###### 1870 | ### do was ovch der marschalch | mit den knehten chomen ### danchwart der vil chvene | der het zv zim genomen ### sines herren ingesinde | von bvergonden lant ### div ross man wol gesatelt | den chvenen nibelvngen vant
###### 1871 | ### do si cen rossen chomen | di chvenege vnde ovch ir man ### volker der starche | raten daz began ### si solden bvhvrdiren | nach ir landes siten ### des wart von den helden | sit vil herlich geritten
###### 1872 | ### der helt het in geraten | des si doch niht verdroz ### der bvhvrt vnt daz shallen | div wurden beide groz ### vffe den hoff vil witen | chom vil manech man ### ecel vnde criemhilt | daz selbe schowen began
###### 1873 | ### vff den bvhvrt chomen | sehs hvndert degene ### der dieteriches rechen | den gesten cegegene ### si wolden chvrcewile | mit den bvrgonden han ### het ers in gegvnnen | si hetenz gerne getan
###### 1874 | ### hey waz gvter rechen | in da nach reit ### dem herren dieteriche | daem wart daz geseit ### mit gvntheres mannen | daz spil er in verbot ### er vorhte siner manne | des gie im sicherlichen not
###### 1875 | ### do dise von berne | gescheiden waren dan ### do chomen von bechelaren | di rvedegeres man ### fvnfhvndert vnder schilde | fver den sal geritten ### liep waere dem margraven | daz siz heten vermitten
###### 1876 | ### do reit er wislichen | zv zin dvrh di schar ### vnde sagete sinen degenen | si waeren des gewar ### daz in vmmvte waeren | di gvntheres man ### ob si den bvhvrt liezen | ez waere im liebe getan
###### 1877 | ### do si von in geschieden | di helde vil gemeit ### da chomen di von dveringen | als vns daz ist geseit ### vnt der von tenemarchen | wol tvsent chvener man ### von stichen sach man vliegen | vil der trvnzvne dan
###### 1878 | ### irnfrit vnde hawart | in den bvhvrt ritten ### ir heten di von rine | vil stolzlich erbitten ### si bvten manige tioste | den von dveringen lant ### des wart von stichen dverchel | vil manich herlicher rant
###### 1879 | ### do chom der herre bloedelin | mit drin tvsent dar ### ecel vnd criemhilt | namen sin vil wol war ### wande vor in beiden | div ritterschapft geshach ### div chveneginne ez gerne | dvrch leit der bvrgonden sach
###### 1880 | ### scrvtan vnde gybecke | vf den bvhvrt ritten ### ramvnch vnd hornboge | nach hivnisschen sitten ### si hielten gegen den helden | von bvrgonden lant ### di shefte draeten hohe | veber des kvneges sals want
###### 1881 | ### swes iemen da pflaege | so was ez niwan schal ### man horte von schilde stoezzen | palas vnde sal ### harte lvt erdiezzen | von gvntheres man ### den lob daz sin gesinde | mit grozen eren gewan
###### 1882 | ### do was ir chvrcewile | so michel vnd groz ### daz dvrch di chovertvere | der blanche sweiz do floz ### von den gvten rossen | div di helde ritten ### si versvchtenz an di hivnen | mit vil hohvertegen sitten
###### 1883 | ### do sprach der chvene recke | volker der spilman ### ich waen vns dise recken | tverren niht bestan ### ich hort ie sagen maere | si waeren vns gehaz ### nv ne chvndez sich gefvegen | zware ninder baz
###### 1884 | ### zen herbergen fveren | sprach aber volfger ### sol man vns di moere | vnd riten danne mer ### gegen abende | so des wirdet zit ### waz op div chvneginne | den lop den bvergonden git
###### 1885 | ### do sahens einen riter | so weigerlichen hie ### daz al der hivnen | getet deheiner nie ### ia moht er in den ziten | wol haben hercentrvt ### er fvor so wol gechleidet | sam eines edeln ritters prvt
###### 1886 | ### do sprach aber volker | wi moeht ich daz verlan ### iener trvt der vrowen | mvz ein gepveze han ### ez chvnde niemen gescheiden | er gat im an den lip ### ichn rvche ich ob ez zverne | des kvenech eceln wip
###### 1887 | ### nein dvrch mine liebe | sprach der kvenech san ### ez wizent vns di livte | vnd ob wir si bestan ### ir lat iz heben di hivnen | daz fveget sich noch baz ### dannoch der kvenech ecel | bi der chveneginne saz
###### 1888 | ### ich wil den bvhvrt meren | sprach do hagene ### lat di vrowen schowen | vnd di degene ### wi wir chvennen riten | daz ist gvt getan ### man git doh lop deheinen | des chvenech gventheres man
###### 1889 | ### volker der vil snelle | den bvhvrt widerreit ### daz wart sit maniger vrowen | vil groezliche leit ### er stach dem richen hivnen | daz sper dvrch sinen lip ### daz sach man sit beweinen | beide maget vnd wip
###### 1890 | ### vil harte hvrtechliche | hagen vnde sine man ### mit sehzech siner degene | riten er began ### nach dem videlaere | da daz spil gesach ### ecel vnde criemhilt | ez besheidenlichen sach
###### 1891 | ### do ne wolden di dri kvenege | den ir spileman ### bi den fianden | niht ane hvte lan ### da wart von tvsent helden | vil crepftelich geritten ### si taten daz si wolden | in vil hohvertechlichen sitten
###### 1892 | ### da der riche hivne | ce tode wart erslagen ### man hort sine mage | rvoffen vnd chlagen ### do rvft al daz gesinde | wer hat ez getan ### daz hat der videlaere | volker der chvene spileman
###### 1893 | ### nach swerten vnd nach schilden | rieffen da zehant ### des margraven mage | von der hivnen lant ### si wolden volkeren | ce tode erslagen han ### der wirt vz einem venster | vil harte gahen began
###### 1894 | ### do hvb sich von den livten | allenthalben schal ### di chvenege vnde ir gesinde | erbeizten fver den sal ### div ross ce rvcke stiezen | di bvergonden man ### do chom der kvenech ecel | der herre ez scheiden began
###### 1895 | ### ein des hivnen mage | den er bi im vant ### ein vil starchez waffen | brach er im vz der hant ### do slvch ers alle widere | wand im was vil zorn ### wi het ich minen dienest | an disen helden verlorn
###### 1896 | ### ob ir hi bi mir slveget | disen spilman ### sprach der kvenech ecel | daz waere missetan ### ich sach vil wol sin riten | do er den hivnen stach ### daz ez von einem strvche | an sine schvlde gesach
###### 1897 | ### ir mvezet mine geste | vride lazen han ### do wart ir geleite | div ross div zoh man dan ### zv den herbergen | si heten manegen kneht ### di im mit vlize waren | zallem dieneste gereht
###### 1898 | ### der wirt mit sinen frivnden | in den palas gie ### zorn er mer deheinen | da niht werden lie ### do rihte man di tissche | daz wazer man in trvch ### da heten di von rine | der starchen viende genvch
###### 1899 | ### e di herren gesazen | des was harte lanch ### div criemhilde sorge | si ce sere twanch ### si sprach fverste von berne | ich svches dinen rat ### helffe vnde genade | min dinch mir angestlichen stat
###### 1900 | ### des antwurte ir hildebrant | der recke lobelich ### swer sleht di nibelvnge | der tvt iz ane mich ### dvrch deheines shazes liebe | ez mach im werden leit ### si sint noch vmbetwungen | di snellen ritter gemeit
###### 1901 | ### do sprach in sinen zvehten | darzv her dieterich ### di bete la beliben | chveneginne rich ### mir habent dine mage | der leide niht getan ### daz ich di degen chvene | mit strite welle bestan
###### 1902 | ### div bet dich lvecel eret | vil edels fversten wip ### daz dv dinen magen | raetest an den lip ### si chomen vf genade | her in diz lant ### sifrit ist vngerochen | von der dieteriches hant
###### 1903 | ### do si der vntruwe | an dem bernaere nine vant ### do lobtes also balde | in bloedelines hant ### eine riche marche | di nvdvnch e besaz ### sit do slvch in danchwart | daz er der gabe gar vergaz
###### 1904 | ### si sprach dv solt mir helffen | herre bloedelin ### ia sint in disem hvse | di viande min ### di slvgen sifriden | den minen lieben man ### swer mir daz hilffet rechen | dem bin ich immer vndertan
###### 1905 | ### des antwurte ir bloedelin | vrowe nv wizzet daz ### ia ne getar ich in vor eceln | geraten cheinen haz ### wande er di dine mage | vro vil gerne sihit ### taet ich in iht ce leide | der kvnech vertrvege mir sin niht
###### 1906 | ### neina herre bloedelin | ich pin dir immer holt ### ia gib ich dir ce miete | silber vnde golt ### vnde eine maget schoene | daz nvdvnges wip ### so maht dv gerne trivten | den ir vil minnechlichen lip
###### 1907 | ### daz lant zv den bvergen | wil ich dir allez geben ### so maht dv ritter edel | mit vrevden immer leben ### gewinnestv di marche | da nvdvnch inne saz ### swaz ich dir gelobe hivte | mit triwen leist ich dir daz
###### 1908 | ### do der herre blodelin | di miete da vernam ### vnt daz im dvrch ir schoene | div vrowe wol gezam ### mit strite wande er dienen | daz minnechliche wip ### darvmbe mvose der recke | do verliesen den lip
###### 1909 | ### er sprach cer chveneginne | get wider in den sal ### e is iemen werde innen | so heb ich einen schal ### ez mvz erarnen hagene | daz er iv hat getan ### ich antwurte iv gebvnden | des kvenech gventheres man
###### 1910 | ### nv waffent ivch sprach blodelin | alle mine man ### wir svln den vianden | in di herberge gan ### des wil mich niht erlazen | daz eceln wip ### darvmbe svln wir helde | alle wagen den lip
###### 1911 | ### do div chveneginne | bloedelinen lie ### in des strites willen | ce thisse si do gie ### mit ecel dem chvenege | vnde ovch mit sinen man ### si hete swinde raete | an di geste getan
###### 1912 | ### do der strit niht anders | chvnde sin erhaben ### criemhilt ir leit daz alte | in ir hercen was begraben ### do hiez si tragen cen tissen | den eceln svn ### wi chvnde ein wip dvrch rache | immer vreislicher getvn
###### 1913 | ### dar giengen an der stvnde | di eceln man ### si trvgen ortlieben | den ivngen kvenech dan ### zv der fversten thisse | da ovch hagen saz ### des mvse daz chint ersterben | dvrch sinen mortlichen haz
###### 1914 | ### do der kvenech riche | sinen svn ersach ### zv sinen chonemagen | er gvetliche sprach ### nv seht ir frivnt di mine | daz ist min einech svn ### vnd ovch iwer swester | daz mach iv allen wesen frvm
###### 1915 | ### gevaehet er nach dem chvenne | ez wirt ein chvene man ### rich vnd vil edel | starch vnde wolgetan ### leb ich deheine wile | ich gip im zwelf lant ### so mag iv wol gedienen | des edeln ortliebes hant
###### 1916 | ### darvmbe bit ich gerne | ivch liebe frivnde min ### swenne ir ce lande ritet | wider an den rin ### so svlt ir mit iv fveren | iwerr swester svn ### vnd svlt ovch an dem chinde | vil genaedechlichen tvn
###### 1917 | ### vnde ziehet in cen eren | vnz er werde ce man ### hat iv in dem lande | iemen iht getan ### daz hilffet er iv rechen | gewehsset im sin lip ### di rede hort ovch criemhilt | des kvenech eceln wip
###### 1918 | ### im solden wol getruwen | dise degene ### gewuehs er ceinem manne | so sprach hagene ### doch ist der kvenech ivnge | so veichlich getan ### man sol mich sehen selten | ce hove nach ortliebe gan
###### 1919 | ### der chvenech an hagenen blichte | div rede was im leit ### swi niht darvmbe redete | der fverste vil gemeit ### ez betrvbete im sin herce | vnde beswarete im den mvt ### do ne was der hagen wille | niht ce chvercewile gvt
###### 1920 | ### ez tet den fversten allen | mit dem kvenege we ### daz hagen von sinem chinde | het gesprochen e ### daz siz vetragen solden | daz was in vngemach ### sin wessen niht der maere | waz von dem recken sit geschach

<<< Übersicht <<< vorige Seite nächste Seite >>>